# ValidityPeriodType

**Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  The period in which the prepayment units are valid to use as defined in a [prepayment charge](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_prepayment_charge). 

## Enum

* `SUBSCRIPTION_TERM` (value: `'SUBSCRIPTION_TERM'`)

* `ANNUAL` (value: `'ANNUAL'`)

* `SEMI_ANNUAL` (value: `'SEMI_ANNUAL'`)

* `QUARTER` (value: `'QUARTER'`)

* `MONTH` (value: `'MONTH'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


